from __future__ import absolute_import

from django.conf import settings
from django.urls import re_path
from django.views import static

from .test_app.views import HomeView, AcceptedView, RejectableView, RejectedView

urlpatterns = [
    re_path(r'^$', HomeView.as_view()),
    re_path('^accepted$', AcceptedView.as_view()),
    re_path('^rejectable$', RejectableView.as_view()),
    re_path('^rejected$', RejectedView.as_view()),

    re_path(r'^static', static.serve, {'document_root': settings.STATIC_ROOT}),
]



import pytest
from selenium.common.exceptions import NoSuchElementException


@pytest.fixture
def selenium(selenium):
    selenium.implicitly_wait(10)
    selenium.maximize_window()
    return selenium


def test_banner_shows_and_hides(selenium, live_server):
    selenium.get(live_server.url)
    cookielaw_banner = selenium.find_element_by_id("CookielawBanner")

    # on click of the button, cookie set and banner hidden
    cookielaw_banner.find_element_by_class_name("btn").click()
    with pytest.raises(NoSuchElementException):
        selenium.find_element_by_id("CookielawBanner")
    assert "1" == selenium.get_cookie("cookielaw_accepted")["value"]

    # on come back, assert banner gone
    selenium.get(live_server.url)

    with pytest.raises(NoSuchElementException):
        selenium.find_element_by_id("CookielawBanner")


def test_text_is_not_rendered_unless_cookies_are_accepted(selenium, live_server):
    selenium.get(f"{live_server.url}/accepted")
    with pytest.raises(NoSuchElementException):
        selenium.find_element_by_id("msg")


def test_when_cookies_are_accepted(selenium, live_server):
    # accept cookies
    selenium.get(live_server.url)
    cookielaw_banner = selenium.find_element_by_id("CookielawBanner")
    cookielaw_banner.find_element_by_class_name("btn").click()

    # go to different page and test if context_processor filled the
    # cookielaw variable
    selenium.get(f"{live_server.url}/accepted")
    msg = selenium.find_element_by_id("msg")
    assert msg
    assert msg.text == "Cookies are good."


def test_reject_cookies_hides_banner(selenium, live_server):
    # load page with rejectable banner and click reject button
    selenium.get(f"{live_server.url}/rejectable")
    selenium.find_element_by_id("CookielawBanner").find_element_by_class_name(
        "reject"
    ).click()

    # reload the page and the banner should not be displayed
    selenium.get(live_server.url)
    with pytest.raises(NoSuchElementException):
        selenium.find_element_by_id("CookielawBanner")


def test_when_cookies_are_rejected(selenium, live_server):
    # load page with rejectable banner and click reject button
    selenium.get(f"{live_server.url}/rejectable")
    selenium.find_element_by_id("CookielawBanner").find_element_by_class_name(
        "reject"
    ).click()

    # go to different page and test if context_processor filled the
    # cookielaw variable
    selenium.get(f"{live_server.url}/rejected")
    msg = selenium.find_element_by_id("msg")
    assert msg
    assert msg.text == "Cookies are bad."



import warnings
import django

from classytags.helpers import InclusionTag
from django import template
from django.template.loader import render_to_string

register = template.Library()


class CookielawBanner(InclusionTag):
    """
    Displays cookie law banner only if user has not dismissed it yet.
    """

    template = "cookielaw/banner.html"

    def render_tag(self, context, **kwargs):
        template_filename = self.get_template(context, **kwargs)

        if "request" not in context:
            warnings.warn(
                "No request object in context. "
                "Are you sure you have django.core.context_processors.request enabled?"
            )
            return ""

        elif context["request"].COOKIES.get("cookielaw_accepted", False):
            return ""

        data = self.get_context(context, **kwargs)

        if django.VERSION[:2] < (1, 10):
            return render_to_string(template_filename, data, context_instance=context)
        else:
            return render_to_string(
                template_filename, data, getattr(context, "request", None)
            )


class RejectableCookielawBanner(CookielawBanner):
    """Displays cookie law banner with options to accept or reject cookies."""

    template = "cookielaw/rejectable.html"


register.tag(CookielawBanner)
register.tag(RejectableCookielawBanner)



import pytest
from django.utils.translation import gettext as _


@pytest.fixture()
def content(client):
    response = client.get("/")
    assert 200 == response.status_code
    return response.content.decode("utf-8")


def test_banner_shows(content):
    assert "CookielawBanner" in content


def test_banner_contains_correct_text(content):
    assert _("COOKIE_INFO_HEADER") in content
    assert _("COOKIE_INFO_PARA") in content
    assert _("COOKIE_INFO_OK") in content



from django.views.generic import TemplateView


class HomeView(TemplateView):
    template_name = 'home.html'


class AcceptedView(TemplateView):
    template_name = 'accepted.html'


class RejectableView(TemplateView):
    template_name = 'rejectable.html'


class RejectedView(TemplateView):
    template_name = 'rejected.html'




def cookielaw(request):
    """Add cookielaw context variable to the context."""

    cookie = request.COOKIES.get('cookielaw_accepted')
    return {
        'cookielaw': {
            'notset': cookie is None,
            'accepted': cookie == '1',
            'rejected': cookie == '0',
        }
    }
